@@ -72,7 +72,7 @@
     </message>
     <message>
         <source>&amp;Cancel</source>
-        <translation type="obsolete">&amp;Annuler</translation>
+        <translation>&amp;Annuler</translation>
     </message>
     <message>
         <source>Install the target reference file.</source>
@@ -86,14 +86,6 @@
         <source>Select a target reference file</source>
         <translation type="unfinished"></translation>
     </message>
-    <message>
-        <source>&amp;Done</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <source>Alt+D</source>
-        <translation type="unfinished"></translation>
-    </message>
 </context>
 <context>
     <name>MonitorValues</name>
@@ -246,7 +238,7 @@
     </message>
     <message>
         <source>2.4</source>
-        <translation type="obsolete">2.4</translation>
+        <translation>2.4</translation>
     </message>
     <message>
         <source>Red or gray Gamma value.</source>
@@ -294,7 +286,7 @@
     </message>
     <message>
         <source>White point:</source>
-        <translation type="obsolete">Point blanc:</translation>
+        <translation>Point blanc:</translation>
     </message>
     <message>
         <source>Select monitor white point. Some monitors refer to this as &apos;temperature&apos;</source>
@@ -318,7 +310,7 @@
     </message>
     <message>
         <source>Primaries:</source>
-        <translation type="obsolete">Primaires:</translation>
+        <translation>Primaires:</translation>
     </message>
     <message>
         <source>Select primaries, if you don&apos;t know what to use, select Rec.709</source>
@@ -373,6 +365,26 @@ Black Point</source>
         <source>Open the Gamma dialog.</source>
         <translation type="unfinished"></translation>
     </message>
+    <message>
+        <source>Set &amp;Gamma and Black Point</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Alt+G</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Red:</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Green:</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Blue:</source>
+        <translation type="unfinished"></translation>
+    </message>
 </context>
 <context>
     <name>ProfileChecker</name>
@@ -404,26 +416,6 @@ Black Point</source>
         <source>Estimated gamma:</source>
         <translation type="unfinished"></translation>
     </message>
-    <message>
-        <source>
-Media white (XYZ):</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <source>Display Profile Missing</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <source>You do not have a display profile
-specified.  Please go back to the
-Preferences tab of the main LProf
-dialog and select a display profile.</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <source>Primaries:</source>
-        <translation type="unfinished">Primaires:</translation>
-    </message>
 </context>
 <context>
     <name>ProfileCheckerBase</name>
@@ -620,7 +612,7 @@ dialog and select a display profile.</source>
     <name>ProfileIDBase</name>
     <message>
         <source>Little CMS Profiler</source>
-        <translation type="obsolete">Little CMS Profiler</translation>
+        <translation>Little CMS Profiler</translation>
     </message>
     <message>
         <source>Profile Information</source>
@@ -730,10 +722,6 @@ dialog and select a display profile.</source>
         <source>Cancel</source>
         <translation type="unfinished"></translation>
     </message>
-    <message>
-        <source>Little CMS Profiler - Profile Identification</source>
-        <translation type="unfinished"></translation>
-    </message>
 </context>
 <context>
     <name>ProfileParms</name>
@@ -952,6 +940,10 @@ dialog and select a display profile.</source>
         <source>Set the Avg. Deviation regression parameter.  Lower values result in a closer fit of the curve to the measurement data points.</source>
         <translation type="unfinished"></translation>
     </message>
+    <message>
+        <source>Lower values result in the curves having a better fit to the measurement data.</source>
+        <translation type="unfinished"></translation>
+    </message>
     <message>
         <source>How dark or light the viewing background is.</source>
         <translation type="unfinished"></translation>
@@ -1128,11 +1120,7 @@ Only color images are supported at this time.</source>
     </message>
     <message>
         <source>  &lt;tr&gt;     &lt;td align=right&gt;Average Target error: (99%% confidence)&lt;/td&gt;     &lt;td&gt;%1&lt;/td&gt;     &lt;td align=right&gt;&lt;font color=blue&gt;Maximum error induced by target itself:&lt;font&gt;&lt;/i&gt;&lt;/td&gt;     &lt;td&gt;%2&lt;/td&gt;   &lt;/tr&gt; </source>
-        <translation type="obsolete">  &lt;tr&gt;     &lt;td align=right&gt;moyenne d&apos;erreur de cible: (99%% confiance)&lt;/td&gt;     &lt;td&gt;%1&lt;/td&gt;     &lt;td align=right&gt;&lt;font color=blue&gt;Taux maximal d&apos;erreurs induites par la cible elle-même :&lt;font&gt;&lt;/i&gt;&lt;/td&gt;     &lt;td&gt;%2&lt;/td&gt;   &lt;/tr&gt; </translation>
-    </message>
-    <message>
-        <source>  &lt;tr&gt;     &lt;td align=right&gt;Average Target error: (99% confidence)&lt;/td&gt;     &lt;td&gt;%1&lt;/td&gt;     &lt;td align=right&gt;&lt;font color=blue&gt;Maximum error induced by target itself:&lt;font&gt;&lt;/i&gt;&lt;/td&gt;     &lt;td&gt;%2&lt;/td&gt;   &lt;/tr&gt; </source>
-        <translation type="unfinished"></translation>
+        <translation>  &lt;tr&gt;     &lt;td align=right&gt;moyenne d&apos;erreur de cible: (99%% confiance)&lt;/td&gt;     &lt;td&gt;%1&lt;/td&gt;     &lt;td align=right&gt;&lt;font color=blue&gt;Taux maximal d&apos;erreurs induites par la cible elle-même :&lt;font&gt;&lt;/i&gt;&lt;/td&gt;     &lt;td&gt;%2&lt;/td&gt;   &lt;/tr&gt; </translation>
     </message>
 </context>
 <context>
@@ -1143,7 +1131,7 @@ Only color images are supported at this time.</source>
     </message>
     <message>
         <source>Gamma</source>
-        <translation type="obsolete">Gamma</translation>
+        <translation>Gamma</translation>
     </message>
     <message>
         <source>Move the slider until shading across chart is most even.</source>
@@ -1171,7 +1159,7 @@ Only color images are supported at this time.</source>
     </message>
     <message>
         <source>2.4</source>
-        <translation type="obsolete">2.4</translation>
+        <translation>2.4</translation>
     </message>
     <message>
         <source>Green Gamma value.</source>
@@ -1179,11 +1167,11 @@ Only color images are supported at this time.</source>
     </message>
     <message>
         <source>Red or gray Gamma value.</source>
-        <translation type="obsolete">Valeur de Gamma rouge ou gris.</translation>
+        <translation>Valeur de Gamma rouge ou gris.</translation>
     </message>
     <message>
         <source>Blue Gamma value.</source>
-        <translation type="obsolete">Valeur de Gamma Bleu.</translation>
+        <translation>Valeur de Gamma Bleu.</translation>
     </message>
     <message>
         <source>B</source>
@@ -1231,7 +1219,7 @@ These charts are used with permission from Norman Koren.  For more
 information see:
 
 http://www.normankoren.com/makingfineprints1A.html#gammachar</source>
-        <translation type="obsolete">Gamma Gebrauch einstellen das oben genannte Diagramm. Wenn der Satz, um 
+        <translation>Gamma Gebrauch einstellen das oben genannte Diagramm. Wenn der Satz, um 
 die gleichmäßigste Farbe zu haben Ihre Anzeige ein Gamma von 2.2 hat. 
 
 Benutzen Sie das Diagramm rechts, in der Einstellung des Monitorschwarzpunktes 
@@ -1258,32 +1246,6 @@ http://www.normankoren.com/makingfineprints1A.html#gammachar</translation>
         <source>Large gamma chart make the area across from 2.2 as even as possible in color.</source>
         <translation type="unfinished"></translation>
     </message>
-    <message>
-        <source>Use the chart to the right to assist in setting the monitor black 
-point (use the brightness control on the monitor).  On the right 
-side of this chart there are two lighter vertical bars.   Bar A 
-should be just visible opposite where gamma = 2.2 on the left 
-side of the chart.  It should no longer be visible by gamma = 1.9.  
-Bar B should be lighter than bar A but still very dark.
-
-These charts are used with permission from Norman Koren.  For 
-more information see:
-
-http://www.normankoren.com/makingfineprints1A.html#gammachar</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <source>Red Gamma value.</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <source>To set gamma use the 
-chart to the right.  When 
-set to have the most 
-even color your display 
-will have a gamma of 2.2.</source>
-        <translation type="unfinished"></translation>
-    </message>
 </context>
 <context>
     <name>Text</name>
@@ -1487,6 +1449,14 @@ Tous les fichiers (*.*)</translation>
         <source>Profile &apos;%1&apos; DONE!</source>
         <translation>Profil &apos;%1&apos; accompli!</translation>
     </message>
+    <message>
+        <source>I have choosen CIE Lab as PCS</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>I have choosen CIE XYZ as PCS</source>
+        <translation type="unfinished"></translation>
+    </message>
     <message>
         <source>White point near %1</source>
         <translation type="unfinished"></translation>
@@ -1523,14 +1493,6 @@ Tous les fichiers (*.*)</translation>
         <source>     Yb:</source>
         <translation type="unfinished"></translation>
     </message>
-    <message>
-        <source>I have chosen CIE Lab as PCS</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <source>I have chosen CIE XYZ as PCS</source>
-        <translation type="unfinished"></translation>
-    </message>
 </context>
 <context>
     <name>lprofMainBase</name>
@@ -1576,7 +1538,7 @@ Tous les fichiers (*.*)</translation>
     </message>
     <message>
         <source>This is the profiler message console</source>
-        <translation type="obsolete">Ceci est la console de message du profileur</translation>
+        <translation>Ceci est la console de message du profileur</translation>
     </message>
     <message>
         <source>Camera/Scanner Profiler</source>
@@ -1844,6 +1806,10 @@ Tous les fichiers (*.*)</translation>
         <source>file parameter information.  This will affect how the profile is created.</source>
         <translation type="unfinished"></translation>
     </message>
+    <message>
+        <source>The profiler message console contains information about the profile that is being created.</source>
+        <translation type="unfinished"></translation>
+    </message>
     <message>
         <source>Press this to bring up a file dialog.</source>
         <translation type="unfinished"></translation>
